--[[	Detailed Durability - Durability Display Module
	by SDPhantom
	https://www.wowinterface.com/forums/member.php?u=34145
	https://www.curseforge.com/members/sdphantomgamer/projects	]]
--------------------------------------------------------------------------

local AddOn=select(2,...);

--------------------------
--[[	Color Hook	]]
--------------------------
--	Called to index INVENTORY_ALERT_COLORS with its return value (0=Normal (no color); 1=Low Durability; 2=Broken)
local AlertStatusIndex;
hooksecurefunc("GetInventoryAlertStatus",function(index) AlertStatusIndex=index; end);

--	Hook INVENTORY_ALERT_COLORS to hand over our custom color
--		Note: PaperDollFrame uses GetInventoryItemTexture() to detect if there's an item in an inventory slot
--		For consistency, we do that too
local CustomColor=CreateColor(1,1,1);--	Init Color Object (It's just an RGB table with metamethods added)
INVENTORY_ALERT_COLORS=setmetatable({},{__index=function()
	local slot=AddOn.AlertToInventorySlotMapping[AlertStatusIndex];--	AlertStatusIndex is the index given to GetInventoryAlertStatus()
	if GetInventoryItemTexture("player",slot) then--	Detect item in inventory slot
		local itemid=GetInventoryItemID("player",slot);
		if slot==INVSLOT_RANGED and not AddOn.GetWeaponType(itemid) then return nil; end--	Is relic slot? (Not a ranged weapon)

		local cur,max=GetInventoryItemDurability(slot);
		if cur and max and not (slot==INVSLOT_RANGED and AddOn.UsesDurabilityForAmmo(itemid)) then--	Item has durability?
			local percent=max>0 and cur/max or 1;
			CustomColor:SetRGB(AddOn.GetPercentColor(percent));--	Fades between green, yellow, and red
		else CustomColor:SetRGB(0.375,0.375,1); end--	Item is indestructible
	else return nil; end--	Hide

	return CustomColor;
end});

----------------------------------
--[[	Offhand Overlap Fix	]]
----------------------------------
AddOn.HookDurabilityUpdate(function()
	DurabilityWeapon:ClearAllPoints();
	DurabilityOffWeapon:ClearAllPoints();
	if GetInventoryItemTexture("player",INVSLOT_RANGED) and C_PaperDollInfo.OffhandHasWeapon() then
		DurabilityWeapon:SetPoint("RIGHT",DurabilityWrists,"LEFT",-20,-6);
		DurabilityOffWeapon:SetPoint("RIGHT",DurabilityWrists,"LEFT",0,-6);
	else
		DurabilityWeapon:SetPoint("RIGHT",DurabilityWrists,"LEFT",0,-6);
		DurabilityOffWeapon:SetPoint("LEFT",DurabilityWrists,"RIGHT",0,-6);
	end
end);

--------------------------
--[[	Extra Events	]]
--------------------------
--	By default, DurabilityFrame only listens to PLAYER_ENTERING_WORLD and UPDATE_INVENTORY_ALERTS
--	The first fires on-load and the second only fires when GetInventoryAlertStatus() changes
DurabilityFrame:UnregisterAllEvents();--	Clear registered events, they're useless to us
DurabilityFrame:RegisterEvent("UPDATE_INVENTORY_DURABILITY");--	Item took durability damage
DurabilityFrame:RegisterEvent("PLAYER_EQUIPMENT_CHANGED");--	Primary Equipped/Unequipped/Swapped items (Ammo slot doesn't fire this in TBC)
DurabilityFrame:RegisterUnitEvent("UNIT_INVENTORY_CHANGED","player");--	Backup Equipped/Unequipped/Swapped items
